@@ -1,48 +1,38 @@
 package Email::Delete;
-# $Id: Delete.pm,v 1.2 2004/12/17 18:45:50 cwest Exp $
 use strict;
+## no critic RequireUseWarnings
+
+=head1 NAME
+
+Email::Delete - Delete Messages from Folders
+
+=head1 VERSION
+
+version 1.021
+
+  $Id: Delete.pm,v 1.2 2004/12/17 18:45:50 cwest Exp $
+
+=cut
 
 use base qw[Exporter];
 use vars qw[@EXPORT_OK $VERSION];
 
 @EXPORT_OK = qw[delete_message];
-$VERSION = '1.02';
+$VERSION = '1.021';
 
 use Email::FolderType qw[folder_type];
 
-sub delete_message {
-    my %args = @_;
-    my $with = $args{with};
-    unless ( $with ) {
-        my $type = folder_type $args{from};
-        $with = __PACKAGE__ . "::$type";
-    }
-
-    eval "use $with"; die if $@;
-
-    no strict 'refs';
-    &{"$with\::delete_message"}(%args);
-}
-
-1;
-
-__END__
-
-=head1 NAME
-
-Email::Delete - Delete Messages from Folders
-
 =head1 SYNOPSIS
 
   use Email::Delete qw[delete_message];
   
   my $message_id = shift @ARGV;
   
-  delete_messages from     => $ENV{MAIL},
-                  matching => sub {
-                      my $message = shift;
-                      $message->header('Message-ID') =~ $message_id;
-                  };
+  delete_message from     => $ENV{MAIL},
+                 matching => sub {
+                   my $message = shift;
+                   $message->header('Message-ID') =~ $message_id;
+                 };
 
 =head1 DESCRIPTION
 
@@ -75,6 +65,23 @@ not delete mail until all the messages have been scanned. So
 if you throw an exception, your mail will be preserved and scanning
 will be aborted.
 
+=cut
+
+sub delete_message {
+    my %args = @_;
+    my $with = $args{with};
+    unless ( $with ) {
+        my $type = folder_type $args{from};
+        $with = __PACKAGE__ . "::$type";
+    }
+
+    eval "use $with"; die if $@;
+
+    $with->can('delete_message')->(%args);
+}
+
+1;
+
 =head1 SEE ALSO
 
 L<Email::Simple>,
